@@ -1,7 +1,7 @@
 test_that("gen_gridcube() works", {
   set.seed(20240412)
   testthat::expect_snapshot(gen_gridcube(n = 500, p = 4))
-  testthat::expect_snapshot(gen_gridcube(n = 500, p = 10))
+  testthat::expect_snapshot(gen_gridcube(n = 500, p = 5))
   testthat::expect_error(gen_gridcube(n = -500, p = 4))
   testthat::expect_error(gen_gridcube(n = 500, p = -4))
 
@@ -10,17 +10,17 @@ test_that("gen_gridcube() works", {
 test_that("gen_unifcube() works", {
   set.seed(20240412)
   testthat::expect_snapshot(gen_unifcube(n = 500, p = 4))
-  testthat::expect_snapshot(gen_unifcube(n = 500, p = 10))
+  testthat::expect_snapshot(gen_unifcube(n = 500, p = 5))
   testthat::expect_error(gen_unifcube(n = -500, p = 4))
   testthat::expect_error(gen_unifcube(n = 500, p = -4))
 
 })
 
-test_that("gen_cubehole() works", {
+test_that("gen_unifcubehole() works", {
   set.seed(20240412)
-  testthat::expect_snapshot(gen_cubehole(n = 1000, p = 4))
-  testthat::expect_snapshot(gen_cubehole(n = 1000, p = 10))
-  testthat::expect_error(gen_cubehole(n = -1000, p = 4))
-  testthat::expect_error(gen_cubehole(n = 1000, p = -4))
+  testthat::expect_snapshot(gen_unifcubehole(n = 1000, p = 4))
+  testthat::expect_snapshot(gen_unifcubehole(n = 1000, p = 10))
+  testthat::expect_error(gen_unifcubehole(n = -1000, p = 4))
+  testthat::expect_error(gen_unifcubehole(n = 1000, p = -4))
 
 })
